# coding=utf-8
from datetime import timedelta


class URL:
    API = 'https://plugin.sc2.zone'
    GITLAB_URL = 'https://git.hotshot.sk/api/v4/'
    LOG_UPLOAD_URL = 'https://paste.kodi.tv/documents'
    OPEN_SUBTITLES = 'https://api.opensubtitles.org/xml-rpc'


class GENERAL:
    PLUGIN_ID = 'plugin.video.stream-cinema-2-release'
    VERSION_CHECK_INTERVAL = timedelta(minutes=1)
    API_TIMEOUT = 20
    VIP_REMAINING_DAYS_WARN = 30
    VIP_CHECK_INTERVAL = timedelta(days=1)
    DEFAULT_LANGUAGE = 'en'
    NEWS_DAYS_LIMIT = 365


class DB_TABLE:
    WATCH_HISTORY = 'watch_history'


class FILTER:
    STARTS_WITH_SIMPLE = 'startsWithSimple'
    GENRE = 'genre'
    SEARCH = 'search'
    SERVICE = 'service'
    PARENT = 'parent'
    ALL = 'all'
    STUDIO = 'studio'
    IDS = 'ids'
    NEWS_DUBBED = 'newsDubbed'
    NEWS = 'news'


class COUNT:
    TITLES = 'titles'
    GENRES = 'genres'
    STUDIOS = 'studios'
    COUNTRIES = 'countries'


class QUERY:
    SORT = 'sort'
    TYPE = 'type'
    ORDER = 'order'
    LANG = 'lang'
    VALUE = 'value'
    SERVICE = 'service'
    ID = 'id'
    DAYS = 'days'


class DIR_TYPE:
    VIDEOS = 'videos'
    MOVIES = 'movies'
    TV_SHOWS = 'tvshows'
    NONE = ''
    EPISODES = 'episodes'


class MEDIA_TYPE:
    TV_SHOW = 'tvshow'
    MOVIE = 'movie'
    SEASON = 'season'
    EPISODE = 'episode'
    ALL = '*'


class ENDPOINT:
    API = '/api'
    MEDIA = API + '/media'
    FILTER = MEDIA + '/filter/{filter_name}?{query}'
    SERVICE = MEDIA + '/service/{service_name}/{service_id}'
    MEDIA_PLAYED = MEDIA + '/played/{media_id}'
    POPULAR = MEDIA + '/popular?{query}'
    MEDIA_DETAIL = MEDIA + '/{media_id}'
    FILTER_COUNT = MEDIA + '/filter/{filter_name}/count/{count_name}?{query}'
    USERS = API + '/users'
    STREAMS = MEDIA + '/{media_id}/streams'


class ORDER:
    ASCENDING = 'asc'
    DESCENDING = 'desc'


class MEDIA_SERVICE:
    CSFD = 'csfd'
    TRAKT = 'trakt'
    TMDB = 'tmdb'
    TVDB = 'tvdb'
    FANART = 'fanart'


class LANG_CODE:
    EN = 'en'
    CS = 'cs'
    SK = 'sk'


languages = {
    LANG_CODE.CS: "Čeština",
    LANG_CODE.SK: "Slovenčina",
    LANG_CODE.EN: "English",
}

lang_code_gui = {
    LANG_CODE.CS: 'CZ',
    LANG_CODE.EN: 'EN',
    LANG_CODE.SK: 'SK'
}

lang_to_iso_3 = {
    LANG_CODE.CS: 'cze',
    LANG_CODE.EN: 'eng',
    LANG_CODE.SK: 'slo'
}


class AUDIO_CHANNEL:
    n6 = 5.1
    n8 = 7.1


audio_channels = {
    6: AUDIO_CHANNEL.n6,
    8: AUDIO_CHANNEL.n8
}


class SORT:
    SCORE = 'score'
    YEAR = 'year'
    PREMIERED = 'premiered'
    DATE_ADDED = 'dateAdded'
    TITLE = 'title'
    PLAY_COUNT = 'playCount'
    LAST_SEEN = 'lastSeen'
    EPISODE = 'episode'
    NEWS = 'news'


class QUALITY:
    n144p = '144p'
    n240p = '240p'
    n360p = '360p'
    n480p = '480p'
    n720p = '720p'
    n1080p = '1080p'
    n2160p = '2160p'
    n4320p = '4320p'


quality_map = {
    144: QUALITY.n144p,
    240: QUALITY.n240p,
    360: QUALITY.n360p,
    480: QUALITY.n480p,
    720: QUALITY.n720p,
    1080: QUALITY.n1080p,
    2160: QUALITY.n2160p,
    4320: QUALITY.n4320p,
}


# ADD SLASH TO MAKE IT VALID
class ROUTE:
    ROOT = 'plugin://plugin.video.stream-cinema-2-release/'
    MOVIES = ROOT + 'movies/'
    TV_SHOWS = ROOT + 'tv_shows/'
    A_TO_Z = ROOT + 'a_to_z/'
    FILTER = ROOT + 'filter/'
    SEARCH = ROOT + 'search/'
    COMMAND = ROOT + 'command/'
    MEDIA_MENU = ROOT + 'media/'
    MAIN_MENU = ROOT + 'main_menu/'
    GENRE_MENU = ROOT + 'genre_menu/'
    SEARCH_RESULT = ROOT + 'search_result/'
    SELECT_STREAM = ROOT + 'select_stream/'
    PLAY_STREAM = ROOT + 'play_stream/'
    POPULAR = ROOT + 'popular/'
    CLEAR_PATH = ROOT + 'clear-path/'
    WATCHED = ROOT + 'watched/'
    CSFD_TIPS = ROOT + 'csfd_tips/'
    GET_MEDIA = ROOT + 'get_media/'
    GET_A_Z_MEDIA = ROOT + 'get_a_z_media/'
    GET_SEARCH_MEDIA = ROOT + 'get_search_media/'
    GET_STREAMS = ROOT + 'get_streams/'
    STUDIO_MENU = ROOT + 'studio_menu/'
    NEXT_PAGE = ROOT + 'next_page/'
    DELETE_HISTORY_ITEM = ROOT + 'delete-history-item/'


class RENDER_TYPE:
    DEFAULT = 'default'
    A_Z = 'a-z'
    SEARCH = 'search'


class CONTEXT_MENU:
    DELETE_HISTORY = 'delete_history'


class GITLAB_ENDPOINT:
    RELEASES = 'projects/{project_id}/releases'


class COMMAND:
    OPEN_SETTINGS = 'open-settings'
    CLEAR_PATH = 'clear-path'
    SHOW_LOG_PATH = 'show-log-path'
    UPLOAD_LOG = 'upload-log'
    ADD_TO_LIBRARY = 'add-to-library'
    CHECK_PROVIDER_CREDENTIALS = 'check-provider-credentials'
    REFRESH_PROVIDER_TOKEN = 'refresh-provider-token'
    SET_PROVIDER_CREDENTIALS = 'set-provider-credentials'
    SET_SUBTITLES_CREDENTIALS = 'set-subtitles-credentials'
    DELETE_HISTORY_ALL = 'delete-history-all'


class HTTP_METHOD:
    GET = 'get'
    POST = 'post'


class REGEX:
    CSFD_ID = r'\/(\d+)-(?!.*\\/\d+-)|^[0-9]+$'


class STORAGE:
    COLLECTION = 'collection'
    MEDIA_LIST = 'media_list'
    PLUGIN_URL_HISTORY = 'plugin_url_history'
    PLUGIN_LAST_URL_ADDED = 'plugin_last_url_added'
    SELECTED_MEDIA_ID = 'selected_media_id'
    SERVICE = 'service'
    CLEARED_CACHE = 'cleared_cache'
    IS_OLD_KODI_SESSION = 'is_new_kodi_session'


class SERVICE:
    PLAYER_SERVICE = 'player_service'


class SERVICE_EVENT:
    PLAYBACK_STARTED = 'playback_started'
    PLAYBACK_STOPPED = 'playback_stopped'


class CACHE:
    EXPIRATION_TIME = 10
    EXPIRATION_TIME_BIGGER = 30
    PLUGIN_URL_HISTORY_LIMIT = 5


class DOWNLOAD_TYPE:
    VIDEO_STREAM = 'video_stream'
    FILE_DOWNLOAD = 'file_download'


class SETTINGS:
    VERSION = 'version'
    UUID = 'uuid'
    DEBUG = 'debug'
    PROVIDER_NAME = 'provider.name'
    PROVIDER_USERNAME = 'provider.username'
    PROVIDER_PASSWORD = 'provider.password'
    PROVIDER_TOKEN = 'provider.token'
    PROVIDER_LOGGED_IN = 'provider.logged_in'
    SHOW_CODEC = 'show_codec'
    SHOW_BITRATE = 'show_bitrate'
    SHOW_DURATION = 'show_duration'
    EXPLICIT_CONTENT = 'explicit_content'
    ADVANCED_CLEAR_CACHE = 'advanced.clear_cache'
    FILE_SIZE_SORT = 'file_size_sort'
    INSTALLATION_DATE = 'installation_date'
    LAST_VERSION_CHECK = 'last_version_check'
    LAST_VERSION_AVAILABLE = 'last_version_available'
    A_Z_THRESHOLD = 'a_z_threshold'
    IS_OUTDATED = 'is_outdated'
    VIP_DURATION = 'provider.vip_duration'
    LAST_VIP_CHECK = 'last_vip_check'
    SHOW_RESULTS_COUNT = 'show_results_count'
    STREAM_AUTOSELECT_PREFERRED_QUALITY = 'auto_select_stream.preferred_quality'
    PREFERRED_LANGUAGE = 'preferred_language'
    FALLBACK_LANGUAGE = 'fallback_language'
    MOVIE_LIBRARY_FOLDER = 'movie_library_folder'
    SHOW_TOP_NAVIGATION = 'show_top_navigation'
    SUBTITLES_PROVIDER_USERNAME = 'subtitles_provider.username'
    SUBTITLES_PROVIDER_PASSWORD = 'subtitles_provider.password'
    SUBTITLES_PROVIDER_TOKEN = 'subtitles_provider.token'
    SUBTITLES_PROVIDER_PREFERRED_LANGUAGE = 'subtitles_provider.preferred_language'
    SUBTITLES_PROVIDER_FALLBACK_LANGUAGE = 'subtitles_provider.fallback_language'
    GENRES_COUNT = 'genres_count'
    PLAYED_ITEMS_HISTORY = 'played_items_history'


class COLOR:
    FLORALWHITE = 'floralwhite'
    BLUE = 'blue'
    RED = 'red'
    IVORY = 'ivory'
    CORNSILK = 'cornsilk'
    LIGHTYELLOW = 'lightyellow'
    GOLD = 'gold'


class STRINGS:
    STREAM_TITLE_BRACKETS = '[{}]'
    STREAM_BITRATE_BRACKETS = '[I]{}[/I]'
    AUDIO_INFO = '[{} {} {}]'
    BOLD = '[B]{}[/B]'
    TABLE_SPACES = '  '
    DATETIME = '%Y-%m-%d %H:%M:%S'
    ISO_FORMAT = '%Y-%m-%dT%H:%M:%S.%f'
    A_TO_Z_TITLE = '{}  [I]({})[/I]'
    REGEX_BRACKETS = '[{}]'
    COLOR = '[COLOR {color}]{text}[/COLOR]'
    COLOR_GREEN = '[COLOR green]{}[/COLOR]'
    COLOR_RED = '[COLOR red]{}[/COLOR]'
    COLOR_BLUE = '[COLOR blue]{}[/COLOR]'
    NEW_LINE = '\n'
    PAIR = '{}: {}'
    PAIR_BOLD = BOLD + ': {}'
    SEASON_TITLE = 'S{season}'
    EPISODE_TITLE = 'E{episode}'
    SEASON_EPISODE_TITLE = 'S{season}E{episode}'
    VIP_INFO = '{} ({}: {})'
    TITLE_YEAR = '{title} [COLOR grey][I]({year})[/I][/COLOR]'
    TITLE_GENRE_YEAR = '{title} [LIGHT][COLOR darkgray]({year}) {genre}[/COLOR][/LIGHT]'
    TV_SHOW_TITLE = '{title}[COLOR grey] · {numbering}[/COLOR]'
    TITLE_AUDIO_INFO = '[COLOR lightskyblue]{audio}[/COLOR][COLOR darkgray] · [/COLOR]{title}'
    TITLE_STREAM_AVAILABLE = '[COLOR red]×[/COLOR] {title}'
    QUERY = '{}?{}'
    TITLE_CHAIN_SEPARATOR = ' - '
    EMPTY = ''
    NEWS_DUBBED_DIR_TITLE = '{title}[COLOR lightskyblue][COLOR darkgray] · [/COLOR]{languages}[/COLOR]'
    SUBTITLES_SEARCH_TITLE = '{title} ({year})'
    NEW_VERSION_AVAILABLE = '[COLOR lightskyblue]{version}[/COLOR] → [COLOR greenyellow]{new_version}[/COLOR]'
    NEW_VERSION_TITLE = '{title} | {versions}'
    CHANGELOG = '{text}\n\n[B]{changelog}[/B]\n{description}'


class CODEC:
    H265 = 'HEVC'
    H264 = 'H264'


class LANG:
    GENERAL = 30010
    SOURCE = 30011
    USERNAME = 30101
    PASSWORD = 30102
    PROVIDER = 30103
    WEBSHARE_CZ = 30104
    ADVANCED = 30012
    INSTALLATION_DATE = 30013
    INTERFACE = 30014
    SHOW_CODEC = 30115
    SHOW_BITRATE = 30116
    THRESHOLDS = 30118
    A_Z_THRESHOLD = 30119
    DEBUG = 30105
    MOVIES = 30200
    SERIES = 30201
    MAIN_MENU = 30202
    NEXT_PAGE = 30203
    SEARCH = 30204
    SEARCH_MEDIA = 30207
    SETTINGS = 30208
    GENRE = 30209
    A_Z = 30210
    POPULAR = 30211
    WATCHING_NOW = 30212
    ACTION = 30213
    ANIMATED = 30214
    ADVENTURE = 30215
    DOCUMENTARY = 30216
    DRAMA = 30217
    EROTIC = 30218
    FANTASY = 30219
    HISTORICAL = 30220
    HORROR = 30221
    MUSIC = 30222
    IMAX = 30223
    CATASTROPHIC = 30224
    COMEDY = 30225
    SHORT = 30226
    CRIME = 30227
    MUSICAL = 30228
    MYSTERIOUS = 30229
    EDUCATIONAL = 30230
    FAIRYTALE = 30231
    PORNOGRAPHIC = 30232
    PSYCHOLOGICAL = 30233
    JOURNALISTIC = 30234
    REALITY = 30235
    TRAVEL = 30236
    FAMILY = 30237
    ROMANTIC = 30238
    SCI_FI = 30239
    COMPETITION = 30240
    SPORTS = 30241
    STAND_UP = 30242
    TALK_SHOW = 30243
    TELENOVELA = 30244
    THRILLER = 30245
    MILITARY = 30246
    WESTERN = 30247
    BIOGRAPHICAL = 30248
    ANIMATION = 30249
    SELECT_A_MEDIA_SOURCE = 30250
    ZERO_NINE = 30251
    SEARCH_FOR_LETTERS = 30252
    CHOOSE_STREAM = 30253
    WATCH_HISTORY = 30254
    BY_STUDIO = 30255
    BY_YEAR = 30256
    BY_COUNTRY = 30257
    BY_DURATION = 30258
    SEASON = 30920
    EPISODE = 30921
    MISSING_PROVIDER_CREDENTIALS = 30300
    NOTHING_FOUND = 30302
    FOUND__NUM__RECORDS = 30303
    ACTIVATE_VIP = 30304
    NEW_VERSION_TITLE = 30307
    NEW_VERSION_TEXT = 30308
    PAGE_LIMIT = 30120
    PROVIDER_DETAILS = 30123
    VERIFY_LOGIN_INFORMATION = 30122
    TOKEN = 30121
    INCORRECT_PROVIDER_CREDENTIALS = 30124
    INFO = 30126
    TOKEN_REFRESHED = 30127
    CORRECT_PROVIDER_CREDENTIALS = 30128
    SHOW_DURATION = 30129
    VIP_REMAINS = 30130
    DAYS = 30132
    NOT_ACTIVE = 30133
    CSFD_TIPS = 30309
    SHOW_SEARCH_RESULTS_NOTIFICATIONS = 30135
    NEWS = 30136
    LAST_ADDED = 30137
    NEWS_DUBBED = 30139
    CHOOSE_LANGUAGE = 30310
    CHOOSE_FALLBACK_LANGUAGE = 30311
    AUTO_SUBTITLES = 30313
    PLUGIN_WAS_UPDATED = 30314
    MISSING_STREAM_TITLE = 30315
    MISSING_STREAM_TEXT = 30316
    CHANGELOG = 30317
    LOG_FILE_PATH = 30410
    PLAYED_ITEMS_HISTORY = 30615
    DELETE_ITEM_FROM_HISTORY = 30616
    DELETE_ALL_HISTORY = 30617
    HISTORY_DELETED = 30618

    # add to library context menu item
    ADD_TO_LIBRARY = 30350

    # network errors
    HTTP_ERROR = 30500
    SERVER_ERROR_HELP = 30501
    CONNECTION_ERROR = 30510
    NO_CONNECTION_HELP = 30511

    # INTRO
    INTRO_TITLE_1 = 30600
    INTRO_TEXT_1 = 30601
    INTRO_TITLE_2 = 30602
    INTRO_TEXT_2 = 30603
    INTRO_TITLE_3 = 30604
    INTRO_TEXT_3 = 30605
    INTRO_TEXT_4 = 30606
    INTRO_TITLE_4 = 30607
    INTRO_TITLE_5 = 30608
    INTRO_TITLE_6 = 30609
    INTRO_TEXT_7 = 30610
    INTRO_TITLE_7 = 30611
    INTRO_TEXT_8 = 30612
    INTRO_TITLE_8 = 30613
    INTRO_TEXT_9 = 30614


class GENRE:
    EROTIC = 'Erotic'
    PORNOGRAPHIC = 'Pornographic'
    ACTION = 'Action'
    ANIMATED = 'Animated'
    ANIMATION = 'Animation'
    ADVENTURE = 'Adventure'
    BIOGRAPHICAL = 'Biographical'
    CATASTROPHIC = 'Catastrophic'
    COMEDY = 'Comedy'
    COMPETITION = 'Competition'
    CRIME = 'Crime'
    DOCUMENTARY = 'Documentary'
    FAIRYTALE = 'Fairytale'
    DRAMA = 'Drama'
    FAMILY = 'Family'
    FANTASY = 'Fantasy'
    HISTORICAL = 'Historical'
    HORROR = 'Horror'
    IMAX = 'IMAX'
    EDUCATIONAL = 'Educational'
    MUSIC = 'Music'
    JOURNALISTIC = 'Journalistic'
    MILITARY = 'Military'
    MUSICAL = 'Musical'
    MYSTERIOUS = 'Mysterious'
    PSYCHOLOGICAL = 'Psychological'
    REALITY = 'Reality'
    ROMANTIC = 'Romantic'
    SCI_FI = 'Sci-Fi'
    SHORT = 'Short'
    SPORTS = 'Sports'
    STAND_UP = 'Stand-Up'
    TALK_SHOW = 'Talk-Show'
    TELENOVELA = 'Telenovela'
    THRILLER = 'Thriller'
    TRAVEL = 'Travel'
    WESTERN = 'Western'


genre_lang = {
    GENRE.EROTIC: LANG.EROTIC,
    GENRE.PORNOGRAPHIC: LANG.PORNOGRAPHIC,
    GENRE.ACTION: LANG.ACTION,
    GENRE.ANIMATED: LANG.ANIMATED,
    GENRE.ANIMATION: LANG.ANIMATION,
    GENRE.ADVENTURE: LANG.ADVENTURE,
    GENRE.BIOGRAPHICAL: LANG.BIOGRAPHICAL,
    GENRE.CATASTROPHIC: LANG.CATASTROPHIC,
    GENRE.COMEDY: LANG.COMEDY,
    GENRE.COMPETITION: LANG.COMPETITION,
    GENRE.CRIME: LANG.CRIME,
    GENRE.DOCUMENTARY: LANG.DOCUMENTARY,
    GENRE.FAIRYTALE: LANG.FAIRYTALE,
    GENRE.DRAMA: LANG.DRAMA,
    GENRE.FAMILY: LANG.FAMILY,
    GENRE.FANTASY: LANG.FANTASY,
    GENRE.HISTORICAL: LANG.HISTORICAL,
    GENRE.HORROR: LANG.HORROR,
    GENRE.IMAX: LANG.IMAX,
    GENRE.EDUCATIONAL: LANG.EDUCATIONAL,
    GENRE.MUSIC: LANG.MUSIC,
    GENRE.JOURNALISTIC: LANG.JOURNALISTIC,
    GENRE.MILITARY: LANG.MILITARY,
    GENRE.MUSICAL: LANG.MUSICAL,
    GENRE.MYSTERIOUS: LANG.MYSTERIOUS,
    GENRE.PSYCHOLOGICAL: LANG.PSYCHOLOGICAL,
    GENRE.REALITY: LANG.REALITY,
    GENRE.ROMANTIC: LANG.ROMANTIC,
    GENRE.SCI_FI: LANG.SCI_FI,
    GENRE.SHORT: LANG.SHORT,
    GENRE.SPORTS: LANG.SPORTS,
    GENRE.STAND_UP: LANG.STAND_UP,
    GENRE.TALK_SHOW: LANG.TALK_SHOW,
    GENRE.TELENOVELA: LANG.TELENOVELA,
    GENRE.THRILLER: LANG.THRILLER,
    GENRE.TRAVEL: LANG.TRAVEL,
    GENRE.WESTERN: LANG.WESTERN
}

explicit_genres = [GENRE.EROTIC, GENRE.PORNOGRAPHIC]

a_z_threshold_options = {
    0: 10,
    1: 20,
    2: 30,
}

page_limit_options = {
    0: 50,
    1: 100,
    2: 150,
    3: 200,
    4: 250,
}


class ICON:
    GENRE = 'genre.png'
    A_Z = 'az.png'
    A_Z_2 = 'az2.png'
    NEW = 'new.png'
    NEW_DUB = 'new_dub.png'
    POPULAR = 'popular.png'
    RECENT = 'recent.png'
    TV = 'csfd.png'
    STUDIO = 'studio.png'
    MOVIES = 'movies.png'
    TVSHOWS = 'tvshows.png'
    HISTORY = 'history.png'
    SEARCH = 'search.png'
    SETTINGS = 'settings.png'
